/*******************************************************************************
*$ Component_name:
*	FKEP_5FREQ
*$ Abstract:
*	Calculates omega, kappa, nu, and the apsidal and nodal precession rates
*	for an orbit as a function of mean orbital radius.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	subroutine	FKEP_5FREQ( a, omega, kappa, nu, apse, node )
*	real*8		a, omega, kappa, nu, apse, node
*$ Inputs:
*	a		mean orbital radius in km.
*$ Outputs:
*	omega		orbital mean motion.
*	kappa		radial (eccentric) oscillation frequency.
*	nu		vertical (inclined) oscillation frequency.
*	apse		apsidal precession frequency.
*	node		nodal regression frequency (generally negative).
*
*	The above are all given in units of radians per second.
*$ Returns:
*	none
*$ Detailed_description:
*	This FORTRAN-callable subroutine returns values for all of the five
*	physically meaningful frequencies associated with an orbit around a
*	planet: omega (mean motion), kappa (radial frequency), nu (vertical
*	frequency), apsidal precession rate, and nodal regression rate.  It
*	should execute faster than any three individual calls to the particular
*	functions FKEP_OMEGA(), FKEP_KAPPA(), FKEP_NU(), FKEP_APSE(), and
*	FKEP_NODE().  Note that the planetary field must have been defined
*	previously using subroutine FKEP_SETPLANET().
*$ External_references:
*	Kep_5Freq()
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Limitations are identical to those for the individual functions
*	FKEP_OMEGA(), FKEP_KAPPA(), FKEP_NU(), FKEP_APSE(), and FKEP_NODE().
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

extern KEP_PLANET fKep_Planet;

void	FORTRAN_NAME(fkep_5freq) ( a, omega, kappa, nu, apse, node )
double	*a, *omega, *kappa, *nu, *apse, *node;
{
	Kep_5Freq( &fKep_Planet, *a, omega, kappa, nu, apse, node );
	return;
}

/******************************************************************************/
