/*******************************************************************************
*$ Component_name:
*	FKEP_APSE
*$ Abstract:
*	Calculates the apsidal precession rate as a function of distance from a
*	planet.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	real*8 function	FKEP_APSE( a )
*	real*8		a
*$ Inputs:
*	a		mean orbital radius in km.
*$ Outputs:
*	none
*$ Returns:
*	apsidal precession rate in radians/second.
*$ Detailed_description:
*	This FORTRAN-callable function returns the apsidal precession rate of an
*	orbit at a given mean radius.  The planetary field must have been
*	defined previously using subroutine FKEP_SETPLANET().
*$ External_references:
*	Kep_Apse(), fKep_Planet
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Result should be exact for infinitesimal perturbations to a small body
*	on a circular orbit about an oblate planet.  Perturbations from the sun
*	and any other moons and rings are not included.  Nonzero eccentricity
*	or inclination would introduce relative errors of order e^2 and
*	sin^2(i).
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

extern KEP_PLANET fKep_Planet;

double	FORTRAN_NAME(fkep_apse) ( a )
double	*a;
{
	return Kep_Apse( &fKep_Planet, *a );
}

/******************************************************************************/
