/*******************************************************************************
*$ Component_name:
*	FKEP_MEANANOM
*$ Abstract:
*	Calculates the mean anomaly of a satellite based on its given
*	eccentricity and true anomaly.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	real*8 function	FKEP_MEANANOM( e, trueAnom )
*	real*8		e, trueAnom
*$ Inputs:
*	e		orbital eccentricity.
*	trueAnom	true anomaly in radians.
*$ Outputs:
*	none
*$ Returns:
*	mean anomaly in radians, between -pi and pi.
*$ Detailed_description:
*	This FORTRAN-callable function returns the mean anomaly of a satellite
*	based on its given eccentricity and true anomaly.  It is the inverse of
*	function FKEP_TRUEANOM().
*$ External_references:
*	Kep_MeanAnom()
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Accuracy will be reduced when eccentricity is close to unity.
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

double	FORTRAN_NAME(fkep_meananom) ( e, trueAnom )
double	*e, *trueAnom;
{
	return Kep_MeanAnom( *e, *trueAnom );
}

/******************************************************************************/
