/*******************************************************************************
*$ Component_name:
*	FKEP_NU
*$ Abstract:
*	Calculates the vertical (inclined) oscillation frequency as a function
*	of distance from a planet.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	real*8 function	FKEP_NU( a )
*	real*8		a
*$ Inputs:
*	a		mean orbital radius in km.
*$ Outputs:
*	none
*$ Returns:
*	vertical oscillation frequency in radians/second.
*$ Detailed_description:
*	This FORTRAN-callable function returns the frequency of vertical
*	(inclined) oscillation "nu" of a body at the given mean distance from
*	a planet center:
*		nu^2 = GM/a^3 (1. + 9/2 J2 (R/a)^2 - 75/8 J4 (R/a)^4 + ...)
*	The planetary field must have been defined previously using subroutine
*	FKEP_SETPLANET().  Cf. FKEP_OMEGA(), FKEP_KAPPA(), FKEP_COMBO().
*$ External_references:
*	Kep_Nu(), fKep_Planet
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Result should be exact for infinitesimal vertical perturbations to a
*	small body on a circular orbit about an oblate planet.  Perturbations
*	from the sun and any other moons and rings are not included.  A nonzero
*	eccentricity or inclination would introduce relative errors of order
*	(e^2 J2 (R/a)^2) and (sin^2(i) J2 (R/a)^2).
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

extern KEP_PLANET fKep_Planet;

double	FORTRAN_NAME(fkep_nu) ( a )
double	*a;
{
	return Kep_Nu( &fKep_Planet, *a );
}

/******************************************************************************/
