/*******************************************************************************
*$ Component_name:
*	FKEP_PRECESS
*$ Abstract:
*	Precesses orbital elements to a new epoch.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	subroutine	FKEP_PRECESS( time, peri, node, meanLon )
*	real*8		time, peri, node, meanLon
*$ Inputs:
*	time		absolute time (sec) of new epoch.
*$ Outputs:
*	peri		new longitude of pericenter (radians).
*	node		new longitude of ascending node (radians).
*	meanLon		new mean longitude of orbiting body (radians).
*$ Returns:
*	none
*$ Detailed_description:
*	This FORTRAN-callable subroutine takes an orbit defined previously using
*	FKEP_SETORBIT() and returns its orbital elements precessed to a new
*	epoch.
*$ External_references:
*	Kep_Precess(), fKep_Orbit
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Orbital rates used for this calculation will be slightly in error for
*	eccentric and/or inclined orbits (cf. FKEP_OMEGA(), FKEP_APSE(), and
*	FKEP_NODE()).
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

extern KEP_ORBIT fKep_Orbit;

void	FORTRAN_NAME(fkep_precess) ( time, peri, node, meanLon )
double	*time, *peri, *node, *meanLon;
{
	Kep_Precess( &fKep_Orbit, *time, peri, node, meanLon );
	return;
}

/******************************************************************************/
