/*******************************************************************************
*$ Component_name:
*	FKEP_SETERROR
*$ Abstract:
*	Changes the precision returned by some Kepler Library routines.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	subroutine	FKEP_SETERROR( error )
*	real*8		error;
*$ Inputs:
*	error		fractional accuracy desired.
*$ Outputs:
*	none
*$ Returns:
*	none
*$ Detailed_description:
*	This FORTRAN-callable function is used to change the fractional accuracy
*	required for the convergence of every Kepler Library module that must
*	iteratively solve a transcendental equation.  A value of zero (the
*	default) indicates that each routine will iterate until full double
*	precision accuracy is obtained, if possible.  If this default behavior
*	is satisfactory, the routine need not be called.  If less precision is
*	needed, calculations may run somewhat faster.  The routines affected by
*	this value are FKEP_SOLVEA(), FKEP_LOCATE(), and FKEP_TRUEANOM().
*$ External_references:
*	Kep_SetError()
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	none
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

void	FORTRAN_NAME(fkep_seterror) ( error )
double	*error;
{
	Kep_SetError( *error );
	return;
}

/******************************************************************************/
