/*******************************************************************************
*$ Component_name:
*	FKEP_SETORBIT
*$ Abstract:
*	Subroutine to define the orbit of a moon around a planet.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	subroutine	FKEP_SETORBIT( a, e, i, peri, node, meanLon, epoch )
*	real*8		a, e, i, peri, node, meanLon, epoch
*$ Inputs:
*	a		semimajor axis (km).
*	e		eccentricity.
*	i		inclination (radians).
*	peri		longitude of pericenter (radians).  This is measured
*			from the reference longitude to the ascending node,
*			and thence along the ring plane.
*	node		longitude of ascending node (radians).
*	meanLon		mean longitude of the orbiting body at the given epoch
*			(radians).
*	epoch		time at which the orbital elements apply (sec).
*$ Outputs:
*	none
*$ Returns:
*	none
*$ Detailed_description:
*	This FORTRAN_callable function is used to define a satellite orbit.  The
*	resultant data is saved in a common for use by other modules of the
*	Kepler Library.  Note that the planetary field must have been defined
*	previously using subroutine FKEP_SETPLANET().
*$ External_references:
*	Kep_SetOrbit, fKep_Orbit, fKep_Planet
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Eccentricity must be less than unity.
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

KEP_ORBIT fKep_Orbit;
extern KEP_PLANET fKep_Planet;

void	FORTRAN_NAME(fkep_setorbit) ( a, e, i, peri, node, meanLon, epoch )
double	*a, *e, *i, *peri, *node, *meanLon, *epoch;
{
	Kep_SetOrbit( *a, *e, *i, *peri, *node, *meanLon, *epoch,
		&fKep_Planet, &fKep_Orbit );
	return;
}
/******************************************************************************/
