/*******************************************************************************
*$ Component_name:
*	FKEP_SETPLANET
*$ Abstract:
*	Subroutine to define the gravitional field of a planet.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	subroutine	FKEP_SETPLANET( radius, gm, js, nJs )
*	real*8		radius, gm, js(*)
*	integer		nJs
*$ Inputs:
*	radius		equatorial radius of planet, in km.
*	gm		gravitation constant G times the mass of the planet, in
*			in km^3/s^2.
*	js(*)		array of gravitational moments J2, J4, J6, etc.
*	nJs		number of moments in array.
*$ Outputs:
*	none
*$ Returns:
*	none
*$ Detailed_description:
*	This FORTRAN-callable function is used to define the gravitional field
*	of a planet.  The field data is saved in a common for access by other
*	modules of the Kepler Library.
*$ External_references:
*	Kep_SetPlanet(), fKep_Planet
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	The maximum number of gravitational moments permitted is defined by the
*	symbol NJ_MAX in file "kepler.h".  It is currently set at 10, allowing
*	moments up to J20.  If more moments are passed in, the list is truncated
*	at J20.  However, this arbitrary limit can be increased by simply
*	changing the defined value in "kepler.h" and re-compiling the entire
*	Kepler Library.
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

KEP_PLANET fKep_Planet;

void	FORTRAN_NAME(fkep_setplanet) ( radius, gm, js, nJs )
double	*radius, *gm, js[];
int	*nJs;
{
	Kep_SetPlanet( *radius, *gm, js, *nJs, &fKep_Planet );
	return;
}
/******************************************************************************/
