/*******************************************************************************
*$ Component_name:
*	FKEP_TRUEANOM
*$ Abstract:
*	Calculates the true anomaly of a satellite based on its given
*	eccentricity and mean anomaly.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	FORTRAN, PUBLIC
*$ Declarations:
*	real*8 function	FKEP_TRUEANOM( e, meanAnom )
*	real*8		e, meanAnom
*$ Inputs:
*	e		orbital eccentricity.
*	meanAnom	mean anomaly in radians.
*$ Outputs:
*	none
*$ Returns:
*	true anomaly in radians, between -pi and pi.
*$ Detailed_description:
*	This FORTRAN-callable function returns the true anomaly of a satellite
*	based on its given eccentricity and mean anomaly.  It is the inverse of
*	function FKEP_MEANANOM().  Note that the accuracy of this result can be
*	controlled by FKEP_SETERROR().
*$ External_references:
*	Kep_TrueAnom()
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Accuracy will be reduced when eccentricity is close to unity.
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "fortran.h"
#include "kepler.h"

double	FORTRAN_NAME(fkep_trueanom) ( e, meanAnom )
double	*e, *meanAnom;
{
	return Kep_TrueAnom( *e, *meanAnom );
}

/******************************************************************************/
