/*******************************************************************************
*$ Component_name:
*	Kep_Apse
*$ Abstract:
*	Calculates the apsidal precession rate as a function of distance from a
*	planet.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	C, PUBLIC, MACRO_DEFINITION
*$ Declarations:
*	double		Kep_Apse( planet, a )
*	KEP_PLANET	*planet;	(typedef defined in "kepler.h")
*	double		a;
*$ Inputs:
*	planet		pointer to a KEP_PLANET structure, as returned by the
*			function Kep_SetPlanet().
*	a		mean orbital radius in km.
*$ Outputs:
*	none
*$ Returns:
*	apsidal precession rate in radians/second.
*$ Detailed_description:
*	This function returns the apsidal precession rate of a body at the given
*	mean distance from a planet center.  It is equivalent to
*	Kep_Combo(planet, a, 1, -1, 0) and is, in fact, defined via a macro
*	in "kepler.h".
*$ External_references:
*	Kep_Combo()
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Result should be exact for infinitesimal perturbations to a small body
*	on a circular orbit about an oblate planet.  Perturbations from the sun
*	and any other moons and rings are not included.  Nonzero eccentricity
*	or inclination would introduce relative errors of order e^2 and
*	sin^2(i).
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
********************************************************************************
* This file is included only for the purpose of documenting the named macro
*******************************************************************************/
