/*******************************************************************************
*$ Component_name:
*	Kep_MeanAnom
*$ Abstract:
*	Calculates the mean anomaly of a satellite based on its given
*	eccentricity and true anomaly.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	C, PUBLIC
*$ Declarations:
*	double		Kep_MeanAnom( e, trueAnom )
*	double		e, trueAnom;
*$ Inputs:
*	e		orbital eccentricity.
*	trueAnom	true anomaly in radians.
*$ Outputs:
*	none
*$ Returns:
*	mean anomaly in radians, between -pi and pi.
*$ Detailed_description:
*	This function returns the mean anomaly of a satellite based on its
*	given eccentricity and true anomaly.  It is the inverse of function
*	Kep_TrueAnom().
*$ External_references:
*	XKep_MeanAnom()
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	Accuracy will be reduced when eccentricity is close to unity.
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include <math.h>
#include "kepler.h"

double	Kep_MeanAnom( e, trueAnom )
double	e, trueAnom;
{
double	eccRatio;

	eccRatio = sqrt( (1.+e) / (1.-e) );
	return XKep_MeanAnom( e, eccRatio, trueAnom );
}

/******************************************************************************/
