/*******************************************************************************
*$ Component_name:
*	Kep_SetError
*$ Abstract:
*	Specifies the precision returned by some Kepler Library routines.
*$ Keywords:
*	KEPLER, ORBITAL_MOTION
*	C, PUBLIC
*$ Declarations:
*	void		Kep_SetError( error )
*	double		error;
*$ Inputs:
*	error		fractional accuracy desired.
*$ Outputs:
*	none
*$ Returns:
*	none
*$ Detailed_description:
*	This function is used to change the fractional accuracy required for the
*	convergence of every Kepler Library module that must iteratively solve a
*	transcendental equation.  A value of zero (the default) indicates that
*	each routine will iterate until full double precision accuracy is
*	obtained, if possible.  If this default behavior is satisfactory, the
*	routine need not be called.  If less precision is needed, calculations
*	may run somewhat faster.  The routines affected by this value are
*	Kep_SolveA(), Kep_Locate(), and Kep_TrueAnom().
*$ External_references:
*	kep_error
*$ Examples:
*	none
*$ Error_handling:
*	none
*$ Limitations:
*	none
*$ Author_and_institution:
*	Mark R. Showalter
*	NASA/Ames Research Center
*$ Version_and_date:
*	1991 June 18
*$ Change_history:
*	none
*******************************************************************************/
#include "kepler.h"

double kep_error = 0.;		/* default value of global variable */

void	Kep_SetError( error )
double	error;
{
	if (error < 0.)	kep_error = 0.;
	else		kep_error = error;

	return;
}

/******************************************************************************/
